==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Downloads/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_CATEGORY","Kategoria");
define("_CATEGORIES","Kategorie");
define("_LVOTES","Gosw");
define("_TOTALVOTES","Razem gosw:");
define("_THEREARE","Aktualnie jest(s)");
define("_NOMATCHES","Brak rezultatw wyszukiwania");
define("_SCOMMENTS","Komentarze");
define("_UNKNOWN","Nieznany");
define("_DOWNLOADS","razy ciagany");
define("_AUTHORNAME","Imi autora");
define("_AUTHOREMAIL","Adres email autora");
define("_DOWNLOADNAME","Nazwa programu");
define("_ADDTHISFILE","Dodaj ten plik");
define("_INBYTES","w bajtach");
define("_FILESIZE","Rozmiar pliku");
define("_VERSION","Wersja");
define("_DESCRIPTION","Opis");
define("_AUTHOR","Autor");
define("_HOMEPAGE","Strona WWW");
define("_DOWNLOADNOW","cignij ten plik teraz!");
define("_RATERESOURCE","Oce ten zasb");
define("_FILEURL","Link do pliku");
define("_ADDDOWNLOAD","Dodaj plik");
define("_DOWNLOADSMAIN","Gwna");
define("_DOWNLOADCOMMENTS","Komentarz");
define("_DOWNLOADSMAINCAT","Gwne kategorie dziau Download");
define("_ADDADOWNLOAD","Dodaj nowy plik");
define("_DSUBMITONCE","Wylij dany plik tylko raz.");
define("_DPOSTPENDING","Wszystkie pliki i linki przed ich opublikowaniem bd sprawdzane.");
define("_RESSORTED","Zawarto aktualnie posortowana wedug");
define("_DOWNLOADSNOTUSER1","Nie jeste zarejestrowanym uytkownikiem albo si nie zalogowae(a).");
define("_DOWNLOADSNOTUSER2","Jeli si zarejestrujesz, bdziesz mg(moga) doda pliki na t stron.");
define("_DOWNLOADSNOTUSER3","Rejestracja uytkownika to atwy i szybki proces.");
define("_DOWNLOADSNOTUSER4","Dlaczego wymagamy rejestracji, aby mie dostp do niektrych opcji?");
define("_DOWNLOADSNOTUSER5","Dlatego, e oferujemy zawarto wycznie wysokiej jakoci,");
define("_DOWNLOADSNOTUSER6","kada pozycja jest indywidualnie sprawdzana i zatwierdzana przez nasz zesp.");
define("_DOWNLOADSNOTUSER7","Mamy nadziej, e oferujemy Ci wycznie wartociowe informacje.");
define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account&amp;op=new_user\">Zarejestruj konto</a>");
define("_DOWNLOADALREADYEXT","BD: Ten adres ju istnieje w bazie!");
define("_DOWNLOADNOTITLE","BD: Musisz poda TYTU Twego URL-a!");
define("_DOWNLOADNOURL","BD: Musisz poda adres Twego URL-a!");
define("_DOWNLOADNODESC","BD: Musisz poda OPIS Twego URL-a!");
define("_DOWNLOADRECEIVED","Otrzymalimy Twoj propozycj do dziau Download. Dzikujemy!");
define("_NEWDOWNLOADS","Nowe pliki");
define("_TOTALNEWDOWNLOADS","W sumie nowych plikw");
define("_DTOTALFORLAST","W sumie nowych plikw w ostatnich");
define("_DBESTRATED","Najwyej ocenione pliki - Top");
define("_TRATEDDOWNLOADS","w sumie ocenionych plikw");
define("_SORTDOWNLOADSBY","Sortuj pliki wedug");
define("_DCATNEWTODAY","Nowe pliki w tej kategorii dodane dzisiaj");
define("_DCATLAST3DAYS","Nowe pliki w tej kategorii dodane w cigu ostatnich 3 dni");
define("_DCATTHISWEEK","Nowe pliki w tej kategorii dodane w cigu ostatniego tygodnia");
define("_DDATE1","Data (Stare pliki umieszczone na pocztku)");
define("_DDATE2","Data (Nowe pliki umieszczone na pocztku)");
define("_DOWNLOADPROFILE","Profil");
define("_DOWNLOADRATINGDET","Szczegy oceniania");
define("_EDITTHISDOWNLOAD","Edytuj ten wpis");
define("_DOWNLOADRATING","Oceny");
define("_DOWNLOADVOTE","Gosuj!");
define("_REQUESTDOWNLOADMOD","Zadaj modyfikacji pliku");
define("_DOWNLOADID","Download ID");
define("_DLETSDECIDE","Wpisy od uytkownikw, takich jak Ty, pomog innym odwiedzajcym zdecydowa si, ktry z plikw warto cign.");
define("_DRATENOTE4","Moesz zobaczy list <a href=\"modules.php?name=Downloads&d_op=TopRated\"> najwyej ocenionych zasobw</a>.");
define("_DATE","Data");
define("_TO","Do");
define("_NEW","Nowy");
define("_POPULAR","Popularno");
define("_TOPRATED","Najwyej ocenione");
define("_ADDITIONALDET","Dodatkowe informacje");
define("_EDITORREVIEW","Przegld redaktora");
define("_REPORTBROKEN","Zgo nieczyne linki");
define("_AND","i");
define("_INDB","w naszej bazie");
define("_INSTRUCTIONS","Instrukcje");
define("_USERANDIP","Nazwa uytkownika i adres IP s rejestrowane, wic prosimy nie atakowa systemu.");
define("_LDESCRIPTION","Opis: (maks. 255 znakw)");
define("_CHECKFORIT","Nie odpisuj na list. W kadym razie sprawdzimy wkrtce Twj link.");
define("_LASTWEEK","Ostatni tydzie");
define("_LAST30DAYS","Oststnie 30 dni");
define("_1WEEK","1 tydzie");
define("_2WEEKS","2 tygodnie");
define("_30DAYS","30 dni");
define("_SHOW","Poka");
define("_DAYS","dni");
define("_ADDEDON","Dodano");
define("_RATING","Rating");
define("_DETAILS","Detale");
define("_OF","z");
define("_TVOTESREQ","minimalna ilo wymaganych gosw");
define("_SHOWTOP","Poka Top");
define("_MOSTPOPULAR","Najbardziej popularne - Top");
define("_OFALL","of all");
define("_POPULARITY","Popularno");
define("_SELECTPAGE","Wybierz stron");
define("_MAIN","Gwna");
define("_NEWTODAY","Nowe dzisiaj");
define("_NEWLAST3DAYS","Nowe w ostatnich 3 dniach");
define("_NEWTHISWEEK","Nowe w tym tygodniu");
define("_POPULARITY1","Popularno (Od najmniej do najczciej odwiedzanych)");
define("_POPULARITY2","Popularno (Od najczciej do najmniej odwiedzanych)");
define("_TITLEAZ","Tytuy (od A do Z)");
define("_TITLEZA","Tytuy (od Z do A)");
define("_RATING1","Ocena (od najniszych do najniszych wynikw)");
define("_RATING2","Ocena (od najwyszych do najniszych wynikw)");
define("_SEARCHRESULTS4","Wyniki wyszukiwania dla");
define("_USUBCATEGORIES","podkategorie");
define("_TRY2SEARCH","Sprbuj poszuka");
define("_INOTHERSENGINES","w innych wyszukiwarkach");
define("_EDITORIAL","Redagowany");
define("_EDITORIALBY","Redagowany przez");
define("_NOEDITORIAL","Aktualnie brak na tej stronie.");
define("_RATETHISSITE","Oce ten zasb");
define("_ISTHISYOURSITE","Czy to Twj zasb?");
define("_ALLOWTORATE","Pozwl innym uytkownikom na ocenianie!");
define("_OVERALLRATING","Ocena oglna");
define("_TOTALOF","Razem");
define("_USER","Uytkownik");
define("_USERAVGRATING","Ocena rednia uytkownika");
define("_NUMRATINGS","# ocen");
define("_REGISTEREDUSERS","Zarejestrowanych uytkownikw");
define("_NUMBEROFRATINGS","Ilo ocen");
define("_NOREGUSERSVOTES","Brak gosw zarejestrowanych uytkownikw");
define("_BREAKDOWNBYVAL","Awaria oceniania poprzez warto");
define("_LTOTALVOTES","razem gosw");
define("_HIGHRATING","Najwysze oceny");
define("_LOWRATING","Najnisze oceny");
define("_NUMOFCOMMENTS","Liczba komentarzy");
define("_WEIGHNOTE","* Nota: Stosunek ocen uytkownikw zarejestrowanych do ocen uytkownikw niezarejestrowanych");
define("_NOUNREGUSERSVOTES","Brak gosw niezarejestrowanych uytkownikw");
define("_WEIGHOUTNOTE","* Nota: Stosunek ocen uytkownikw zarejestrowanych do ocen innych uytkownikw");
define("_NOOUTSIDEVOTES","Brak zewntrznych gosw");
define("_OUTSIDEVOTERS","Gosujcy z zewntrz");
define("_UNREGISTEREDUSERS","Niezarejestrowanych uytkownikw");
define("_PROMOTEYOURSITE","Wypromuj swoj stron");
define("_PROMOTE01","Moe jeste zainteresowany(a) kilkoma dostpnymi opcjami zdalnego oceniania strony?. To pozwoli Ci umieci obraz (lub nawet formularz) na Twojej stronie, aby podnie liczb gosw na Twoj stron. Prosimy wybra jedn z opcji umieszczonych poniej:");
define("_TEXTLINK","Tekst linku");
define("_PROMOTE02","Jedyny sposb podczenia si do formularza ocen to prosty link tekstowy:");
define("_HTMLCODE1","Kod HTML, ktry trzeba zastosowa w tym przypadku, to:");
define("_THENUMBER","Numer");
define("_IDREFER","Numer ID Twojej strony w bazie danych $sitename. Upewnij si, czy taki numer istnieje.");
define("_BUTTONLINK","Link przyciskowy");
define("_PROMOTE03","Jeli szukasz niewiele ponad prosty link tekstowy, to moe chcesz zastosowa link przyciskowy:");
define("_RATEIT","Oce t stron!");
define("_HTMLCODE2","Kod rdowy powyszego przycisku to:");
define("_REMOTEFORM","Zdalny formularz gosowania");
define("_PROMOTE04","Jeeli bedzisz tu oszukiwa, usuniemy Twj link. Mwimy, e to jest zdalny formularz gosowania, ktry wyglda jak.");
define("_VOTE4THISSITE","Gosuj na t stron!");
define("_HTMLCODE3","Uycie tego formularza powoli uytkownikom na ocen Twego zasobu bezporednio z Twojej strony i zapisanie wyniku tutaj. Powyszy formularz jestwyczony, ale nastpujcy kod rdowy bdzie dziaa jeeli po prostu skopiujesz go i wkleisz na swoj stron. Kod rdowy pokazujemy poniej:");
define("_PROMOTE05","Dzikujemy! Powodzenia w ocenach!");
define("_STAFF","Zesp");
define("_THANKSBROKEN","Dzikujemy za pomoc w utrzymaniu integralnoci tego katalogu.");
define("_SECURITYBROKEN","Z powodw bezpieczestwa Twoja nazwa uytkownika i adres IP bd tymczasowo zapisywane.");
define("_THANKSFORINFO","Dzikujemy za informacje.");
define("_LOOKTOREQUEST","Zajrzymy niebawem w Twoj sugesti.");
define("_SENDREQUEST","Wylij danie");
define("_THANKSTOTAKETIME","Dzikujemy za spdzenie czasu na ocen strony");
define("_RETURNTO","Powrt do");
define("_RATENOTE1","Prosimy nie gosowa na ten sam zasb wicej ni raz.");
define("_RATENOTE2","Skala jest od 1 do 10, gdzie 1 znaczy kiepski i 10 znaczy wspaniay.");
define("_RATENOTE3","Prosimy o obiektywizm w gosowaniu, jeli kto otrzyma 1 i 10, ocena nie bdzie zbyt uyteczna.");
define("_RATENOTE5","Nie gosuj na wasne zasoby lub zasoby konkurencji.");
define("_YOUAREREGGED","Jeste zarejestrowanym i zalogowanym uytkownikiem.");
define("_FEELFREE2ADD","Swobodnie dodaj komentarz na temat tej strony.");
define("_YOUARENOTREGGED","Nie jeste zarejestrowanym uytkownikiem lub si nie zalogowae(a).");
define("_IFYOUWEREREG","Jeli si zarejestrujesz, moesz dodawa komentarze na tej stronie.");
define("_TITLE","Tytu");
define("_MODIFY","Modyfikuj");
define("_COMPLETEVOTE1","Twj gos ma due znaczenie dla nas.");
define("_COMPLETEVOTE2","Gosowae na ten zasb $anonwaitdays dni temu.");
define("_COMPLETEVOTE3","Gosuj tylko raz.<br>Wszystkie gosy s logowane i sprawdzane.");
define("_COMPLETEVOTE4","Nie moesz gosowa na link, ktry sam dodae.<br>Wszystkie gosy s logowane i sprawdzane.");
define("_COMPLETEVOTE5","Nie wybrana ocena - gos nie zaliczony");
define("_COMPLETEVOTE6","Tylko jeden gos dozwolony raz na $outsidewaitdays dzie.");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Downloads/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_CATEGORY","Kategoria");
define("_CATEGORIES","Kategorie");
define("_LVOTES","Gosw");
define("_TOTALVOTES","Razem gosw:");
define("_THEREARE","Aktualnie jest(s)");
define("_NOMATCHES","Brak rezultatw wyszukiwania");
define("_SCOMMENTS","Komentarze");
define("_UNKNOWN","Nieznany");
define("_DOWNLOADS","razy ciagany");
define("_AUTHORNAME","Imi autora");
define("_AUTHOREMAIL","Adres email autora");
define("_DOWNLOADNAME","Nazwa programu");
define("_ADDTHISFILE","Dodaj ten plik");
define("_INBYTES","w bajtach");
define("_FILESIZE","Rozmiar pliku");
define("_VERSION","Wersja");
define("_DESCRIPTION","Opis");
define("_AUTHOR","Autor");
define("_HOMEPAGE","Strona WWW");
define("_DOWNLOADNOW","cignij ten plik teraz!");
define("_RATERESOURCE","Oce ten zasb");
define("_FILEURL","Link do pliku");
define("_ADDDOWNLOAD","Dodaj plik");
define("_DOWNLOADSMAIN","Gwna");
define("_DOWNLOADCOMMENTS","Komentarz");
define("_DOWNLOADSMAINCAT","Gwne kategorie dziau Download");
define("_ADDADOWNLOAD","Dodaj nowy plik");
define("_DSUBMITONCE","Wylij dany plik tylko raz.");
define("_DPOSTPENDING","Wszystkie pliki i linki przed ich opublikowaniem bd sprawdzane.");
define("_RESSORTED","Zawarto aktualnie posortowana wedug");
define("_DOWNLOADSNOTUSER1","Nie jeste zarejestrowanym uytkownikiem albo si nie zalogowae(a).");
define("_DOWNLOADSNOTUSER2","Jeli si zarejestrujesz, bdziesz mg(moga) doda pliki na t stron.");
define("_DOWNLOADSNOTUSER3","Rejestracja uytkownika to atwy i szybki proces.");
define("_DOWNLOADSNOTUSER4","Dlaczego wymagamy rejestracji, aby mie dostp do niektrych opcji?");
define("_DOWNLOADSNOTUSER5","Dlatego, e oferujemy zawarto wycznie wysokiej jakoci,");
define("_DOWNLOADSNOTUSER6","kada pozycja jest indywidualnie sprawdzana i zatwierdzana przez nasz zesp.");
define("_DOWNLOADSNOTUSER7","Mamy nadziej, e oferujemy Ci wycznie wartociowe informacje.");
define("_DOWNLOADSNOTUSER8","<a href=\"modules.php?name=Your_Account&amp;op=new_user\">Zarejestruj konto</a>");
define("_DOWNLOADALREADYEXT","BD: Ten adres ju istnieje w bazie!");
define("_DOWNLOADNOTITLE","BD: Musisz poda TYTU Twego URL-a!");
define("_DOWNLOADNOURL","BD: Musisz poda adres Twego URL-a!");
define("_DOWNLOADNODESC","BD: Musisz poda OPIS Twego URL-a!");
define("_DOWNLOADRECEIVED","Otrzymalimy Twoj propozycj do dziau Download. Dzikujemy!");
define("_NEWDOWNLOADS","Nowe pliki");
define("_TOTALNEWDOWNLOADS","W sumie nowych plikw");
define("_DTOTALFORLAST","W sumie nowych plikw w ostatnich");
define("_DBESTRATED","Najwyej ocenione pliki - Top");
define("_TRATEDDOWNLOADS","w sumie ocenionych plikw");
define("_SORTDOWNLOADSBY","Sortuj pliki wedug");
define("_DCATNEWTODAY","Nowe pliki w tej kategorii dodane dzisiaj");
define("_DCATLAST3DAYS","Nowe pliki w tej kategorii dodane w cigu ostatnich 3 dni");
define("_DCATTHISWEEK","Nowe pliki w tej kategorii dodane w cigu ostatniego tygodnia");
define("_DDATE1","Data (Stare pliki umieszczone na pocztku)");
define("_DDATE2","Data (Nowe pliki umieszczone na pocztku)");
define("_DOWNLOADPROFILE","Profil");
define("_DOWNLOADRATINGDET","Szczegy oceniania");
define("_EDITTHISDOWNLOAD","Edytuj ten wpis");
define("_DOWNLOADRATING","Oceny");
define("_DOWNLOADVOTE","Gosuj!");
define("_REQUESTDOWNLOADMOD","Zadaj modyfikacji pliku");
define("_DOWNLOADID","Download ID");
define("_DLETSDECIDE","Wpisy od uytkownikw, takich jak Ty, pomog innym odwiedzajcym zdecydowa si, ktry z plikw warto cign.");
define("_DRATENOTE4","Moesz zobaczy list <a href=\"modules.php?name=Downloads&d_op=TopRated\"> najwyej ocenionych zasobw</a>.");
define("_DATE","Data");
define("_TO","Do");
define("_NEW","Nowy");
define("_POPULAR","Popularno");
define("_TOPRATED","Najwyej ocenione");
define("_ADDITIONALDET","Dodatkowe informacje");
define("_EDITORREVIEW","Przegld redaktora");
define("_REPORTBROKEN","Zgo nieczyne linki");
define("_AND","i");
define("_INDB","w naszej bazie");
define("_INSTRUCTIONS","Instrukcje");
define("_USERANDIP","Nazwa uytkownika i adres IP s rejestrowane, wic prosimy nie atakowa systemu.");
define("_LDESCRIPTION","Opis: (maks. 255 znakw)");
define("_CHECKFORIT","Nie odpisuj na list. W kadym razie sprawdzimy wkrtce Twj link.");
define("_LASTWEEK","Ostatni tydzie");
define("_LAST30DAYS","Oststnie 30 dni");
define("_1WEEK","1 tydzie");
define("_2WEEKS","2 tygodnie");
define("_30DAYS","30 dni");
define("_SHOW","Poka");
define("_DAYS","dni");
define("_ADDEDON","Dodano");
define("_RATING","Rating");
define("_DETAILS","Detale");
define("_OF","z");
define("_TVOTESREQ","minimalna ilo wymaganych gosw");
define("_SHOWTOP","Poka Top");
define("_MOSTPOPULAR","Najbardziej popularne - Top");
define("_OFALL","of all");
define("_POPULARITY","Popularno");
define("_SELECTPAGE","Wybierz stron");
define("_MAIN","Gwna");
define("_NEWTODAY","Nowe dzisiaj");
define("_NEWLAST3DAYS","Nowe w ostatnich 3 dniach");
define("_NEWTHISWEEK","Nowe w tym tygodniu");
define("_POPULARITY1","Popularno (Od najmniej do najczciej odwiedzanych)");
define("_POPULARITY2","Popularno (Od najczciej do najmniej odwiedzanych)");
define("_TITLEAZ","Tytuy (od A do Z)");
define("_TITLEZA","Tytuy (od Z do A)");
define("_RATING1","Ocena (od najniszych do najniszych wynikw)");
define("_RATING2","Ocena (od najwyszych do najniszych wynikw)");
define("_SEARCHRESULTS4","Wyniki wyszukiwania dla");
define("_USUBCATEGORIES","podkategorie");
define("_TRY2SEARCH","Sprbuj poszuka");
define("_INOTHERSENGINES","w innych wyszukiwarkach");
define("_EDITORIAL","Redagowany");
define("_EDITORIALBY","Redagowany przez");
define("_NOEDITORIAL","Aktualnie brak na tej stronie.");
define("_RATETHISSITE","Oce ten zasb");
define("_ISTHISYOURSITE","Czy to Twj zasb?");
define("_ALLOWTORATE","Pozwl innym uytkownikom na ocenianie!");
define("_OVERALLRATING","Ocena oglna");
define("_TOTALOF","Razem");
define("_USER","Uytkownik");
define("_USERAVGRATING","Ocena rednia uytkownika");
define("_NUMRATINGS","# ocen");
define("_REGISTEREDUSERS","Zarejestrowanych uytkownikw");
define("_NUMBEROFRATINGS","Ilo ocen");
define("_NOREGUSERSVOTES","Brak gosw zarejestrowanych uytkownikw");
define("_BREAKDOWNBYVAL","Awaria oceniania poprzez warto");
define("_LTOTALVOTES","razem gosw");
define("_HIGHRATING","Najwysze oceny");
define("_LOWRATING","Najnisze oceny");
define("_NUMOFCOMMENTS","Liczba komentarzy");
define("_WEIGHNOTE","* Nota: Stosunek ocen uytkownikw zarejestrowanych do ocen uytkownikw niezarejestrowanych");
define("_NOUNREGUSERSVOTES","Brak gosw niezarejestrowanych uytkownikw");
define("_WEIGHOUTNOTE","* Nota: Stosunek ocen uytkownikw zarejestrowanych do ocen innych uytkownikw");
define("_NOOUTSIDEVOTES","Brak zewntrznych gosw");
define("_OUTSIDEVOTERS","Gosujcy z zewntrz");
define("_UNREGISTEREDUSERS","Niezarejestrowanych uytkownikw");
define("_PROMOTEYOURSITE","Wypromuj swoj stron");
define("_PROMOTE01","Moe jeste zainteresowany(a) kilkoma dostpnymi opcjami zdalnego oceniania strony?. To pozwoli Ci umieci obraz (lub nawet formularz) na Twojej stronie, aby podnie liczb gosw na Twoj stron. Prosimy wybra jedn z opcji umieszczonych poniej:");
define("_TEXTLINK","Tekst linku");
define("_PROMOTE02","Jedyny sposb podczenia si do formularza ocen to prosty link tekstowy:");
define("_HTMLCODE1","Kod HTML, ktry trzeba zastosowa w tym przypadku, to:");
define("_THENUMBER","Numer");
define("_IDREFER","Numer ID Twojej strony w bazie danych $sitename. Upewnij si, czy taki numer istnieje.");
define("_BUTTONLINK","Link przyciskowy");
define("_PROMOTE03","Jeli szukasz niewiele ponad prosty link tekstowy, to moe chcesz zastosowa link przyciskowy:");
define("_RATEIT","Oce t stron!");
define("_HTMLCODE2","Kod rdowy powyszego przycisku to:");
define("_REMOTEFORM","Zdalny formularz gosowania");
define("_PROMOTE04","Jeeli bedzisz tu oszukiwa, usuniemy Twj link. Mwimy, e to jest zdalny formularz gosowania, ktry wyglda jak.");
define("_VOTE4THISSITE","Gosuj na t stron!");
define("_HTMLCODE3","Uycie tego formularza powoli uytkownikom na ocen Twego zasobu bezporednio z Twojej strony i zapisanie wyniku tutaj. Powyszy formularz jestwyczony, ale nastpujcy kod rdowy bdzie dziaa jeeli po prostu skopiujesz go i wkleisz na swoj stron. Kod rdowy pokazujemy poniej:");
define("_PROMOTE05","Dzikujemy! Powodzenia w ocenach!");
define("_STAFF","Zesp");
define("_THANKSBROKEN","Dzikujemy za pomoc w utrzymaniu integralnoci tego katalogu.");
define("_SECURITYBROKEN","Z powodw bezpieczestwa Twoja nazwa uytkownika i adres IP bd tymczasowo zapisywane.");
define("_THANKSFORINFO","Dzikujemy za informacje.");
define("_LOOKTOREQUEST","Zajrzymy niebawem w Twoj sugesti.");
define("_SENDREQUEST","Wylij danie");
define("_THANKSTOTAKETIME","Dzikujemy za spdzenie czasu na ocen strony");
define("_RETURNTO","Powrt do");
define("_RATENOTE1","Prosimy nie gosowa na ten sam zasb wicej ni raz.");
define("_RATENOTE2","Skala jest od 1 do 10, gdzie 1 znaczy kiepski i 10 znaczy wspaniay.");
define("_RATENOTE3","Prosimy o obiektywizm w gosowaniu, jeli kto otrzyma 1 i 10, ocena nie bdzie zbyt uyteczna.");
define("_RATENOTE5","Nie gosuj na wasne zasoby lub zasoby konkurencji.");
define("_YOUAREREGGED","Jeste zarejestrowanym i zalogowanym uytkownikiem.");
define("_FEELFREE2ADD","Swobodnie dodaj komentarz na temat tej strony.");
define("_YOUARENOTREGGED","Nie jeste zarejestrowanym uytkownikiem lub si nie zalogowae(a).");
define("_IFYOUWEREREG","Jeli si zarejestrujesz, moesz dodawa komentarze na tej stronie.");
define("_TITLE","Tytu");
define("_MODIFY","Modyfikuj");
define("_COMPLETEVOTE1","Twj gos ma due znaczenie dla nas.");
define("_COMPLETEVOTE2","Gosowae na ten zasb $anonwaitdays dni temu.");
define("_COMPLETEVOTE3","Gosuj tylko raz.<br>Wszystkie gosy s logowane i sprawdzane.");
define("_COMPLETEVOTE4","Nie moesz gosowa na link, ktry sam dodae.<br>Wszystkie gosy s logowane i sprawdzane.");
define("_COMPLETEVOTE5","Nie wybrana ocena - gos nie zaliczony");
define("_COMPLETEVOTE6","Tylko jeden gos dozwolony raz na $outsidewaitdays dzie.");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
